| BIB | R Documentation |
Builds the symmetric balanced incomplete block design (BIBD) whose treatments are the points of the projective geometry PG(m, p) over the Galois field GF(p) and whose blocks are its hyperplanes.
BIB(m, p = 2)
m |
Dimension of the projective geometry (an integer, |
p |
Order of the Galois field GF(p); must be prime. Defaults to
|
Treatments are numbered by enumerating the canonical
representatives of the projective points in base-p counting order. Block
i consists of the points x lying on the hyperplane
a_i . x = 0 (mod p), where a_i is the i-th point
(point-hyperplane duality).
A list with components:
VNumber of treatments, (p^{m+1}-1)/(p-1).
BNumber of blocks (equal to V: the design is
symmetric).
RReplication of each treatment, (p^m-1)/(p-1).
KBlock size (equal to R).
LambdaConcurrence parameter, (p^{m-1}-1)/(p-1).
BIBThe design: a B x K matrix whose rows
are the blocks, containing treatment labels.
Mohamed Laib, Abla Boudraa and Zebida Gheribi-Aoulmi
A. Boudraa, Z. Gheribi-Aoulmi and M. Laib (2013). Recursive method for construction of resolvable nested designs and uniform designs associated. International Journal of Research and Reviews in Applied Sciences, 17(2), 167–176.
D. Dugue (1958). Traite de statistique theorique et appliquee. Masson et Cie, Paris.
X <- BIB(4) # BIBD (31, 15, 7) from PG(4, 2)
X$V; X$K; X$Lambda
Y <- BIB(2, p = 3) # BIBD (13, 4, 1): the projective plane of order 3
Y$BIB
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.